@@ -8,8 +8,10 @@ import (
 	"github.com/abiosoft/colima/util"
 )
 
-const AppName = "colima"
-const SubprocessProfileEnvVar = "COLIMA_PROFILE"
+const (
+	AppName                 = "colima"
+	SubprocessProfileEnvVar = "COLIMA_PROFILE"
+)
 
 var profile = ProfileInfo{ID: AppName, DisplayName: AppName, ShortName: "default"}
 
@@ -77,6 +79,9 @@ type Config struct {
 	Network      Network           `yaml:"network,omitempty"`
 	Env          map[string]string `yaml:"env,omitempty"` // environment variables
 
+	// VM VMType
+	VMType string `yaml:"vmType,omitempty"`
+
 	// volume mounts
 	Mounts    []Mount `yaml:"mounts,omitempty"`
 	MountType string  `yaml:"mountType,omitempty"`
@@ -96,20 +101,23 @@ type Config struct {
 
 	// provision scripts
 	Provision []Provision `yaml:"provision,omitempty"`
+
+	// SSH config generation
+	SSHConfig bool `yaml:"sshConfig,omitempty"`
 }
 
 // Kubernetes is kubernetes configuration
 type Kubernetes struct {
-	Enabled bool   `yaml:"enabled"`
-	Version string `yaml:"version"`
-	Ingress bool   `yaml:"ingress"`
+	Enabled bool     `yaml:"enabled"`
+	Version string   `yaml:"version"`
+	Disable []string `yaml:"disable"`
 }
 
 // Network is VM network configuration
 type Network struct {
-	Address bool     `yaml:"address"`
-	DNS     []net.IP `yaml:"dns"`
-	Driver  string   `yaml:"driver"`
+	Address      bool              `yaml:"address"`
+	DNSResolvers []net.IP          `yaml:"dns"`
+	DNSHosts     map[string]string `yaml:"dnsHosts"`
 }
 
 // Mount is volume mount
@@ -150,3 +158,10 @@ func (c Config) Empty() bool { return c.Runtime == "" } // this may be better bu
 func CtxKey() any {
 	return struct{ name string }{name: "colima_config"}
 }
+
+func (c Config) DriverLabel() string {
+	if util.MacOS13OrNewer() && c.VMType == "vz" {
+		return "macOS Virtualization.Framework"
+	}
+	return "QEMU"
+}
