@@ -98,6 +98,6 @@ func TemplatesDir() string { return templatesDir.Dir() }
 // WrapperDir returns the qemu wrapper directory.
 func WrapperDir() string { return wrapperDir.Dir() }
 
-const configFileName = "colima.yaml"
+const ConfigFileName = "colima.yaml"
 
-func configFile() string { return filepath.Join(configDir.Dir(), configFileName) }
+func configFile() string { return filepath.Join(configDir.Dir(), ConfigFileName) }
