@@ -7,7 +7,6 @@ import (
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process"
-	"github.com/abiosoft/colima/daemon/process/gvproxy"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/util/fsutil"
@@ -69,10 +68,10 @@ func (l processManager) Running(ctx context.Context) (s Status, err error) {
 	}
 	s.Running = true
 
-	for _, process := range processesFromCtx(ctx) {
-		pErr := process.Alive(ctx)
+	for _, p := range processesFromCtx(ctx) {
+		pErr := p.Alive(ctx)
 		s.Processes = append(s.Processes, processStatus{
-			Name:    process.Name(),
+			Name:    p.Name(),
 			Running: pErr == nil,
 			Error:   pErr,
 		})
@@ -92,12 +91,6 @@ func (l processManager) Start(ctx context.Context) error {
 	if opts.Vmnet {
 		args = append(args, "--vmnet")
 	}
-	if opts.GVProxy {
-		args = append(args, "--gvproxy")
-	}
-	if opts.FSNotify {
-		args = append(args, "--fsnotify")
-	}
 
 	if cli.Settings.Verbose {
 		args = append(args, "--verbose")
@@ -114,16 +107,13 @@ func (l processManager) Stop(ctx context.Context) error {
 
 func optsFromCtx(ctx context.Context) struct {
 	Vmnet    bool
-	GVProxy  bool
 	FSNotify bool
 } {
 	var opts = struct {
 		Vmnet    bool
-		GVProxy  bool
 		FSNotify bool
 	}{}
 	opts.Vmnet, _ = ctx.Value(CtxKey(vmnet.Name)).(bool)
-	opts.GVProxy, _ = ctx.Value(CtxKey(gvproxy.Name)).(bool)
 
 	return opts
 }
@@ -135,9 +125,6 @@ func processesFromCtx(ctx context.Context) []process.Process {
 	if opts.Vmnet {
 		processes = append(processes, vmnet.New())
 	}
-	if opts.GVProxy {
-		processes = append(processes, gvproxy.New())
-	}
 
 	return processes
 }
