@@ -20,11 +20,11 @@ func installK3s(host environment.HostActions,
 	log *logrus.Entry,
 	containerRuntime string,
 	k3sVersion string,
-	ingress bool,
+	disable []string,
 ) {
 	installK3sBinary(host, guest, a, k3sVersion)
 	installK3sCache(host, guest, a, log, containerRuntime, k3sVersion)
-	installK3sCluster(host, guest, a, containerRuntime, k3sVersion, ingress)
+	installK3sCluster(host, guest, a, containerRuntime, k3sVersion, disable)
 }
 
 func installK3sBinary(
@@ -97,7 +97,6 @@ func installK3sCache(
 			return nil
 		})
 	}
-
 }
 
 func installK3sCluster(
@@ -106,7 +105,7 @@ func installK3sCluster(
 	a *cli.ActiveCommandChain,
 	containerRuntime string,
 	k3sVersion string,
-	ingress bool,
+	disable []string,
 ) {
 	// install k3s last to ensure it is the last step
 	downloadPath := "/tmp/k3s-install.sh"
@@ -123,8 +122,8 @@ func installK3sCluster(
 		"--resolv-conf", "/etc/resolv.conf",
 	}
 
-	if !ingress {
-		args = append(args, "--disable", "traefik")
+	for _, d := range disable {
+		args = append(args, "--disable", d)
 	}
 
 	// replace ip address if networking is enabled
@@ -146,5 +145,4 @@ func installK3sCluster(
 	a.Add(func() error {
 		return guest.Run("sh", "-c", "INSTALL_K3S_SKIP_DOWNLOAD=true INSTALL_K3S_SKIP_ENABLE=true k3s-install.sh "+strings.Join(args, " "))
 	})
-
 }
