@@ -104,11 +104,6 @@ func newConf(ctx context.Context, conf config.Config) (l Config, err error) {
 			Script: `grep -q "^rc_env_allow" /etc/rc.conf || echo 'rc_env_allow="*"' >> /etc/rc.conf`,
 		})
 
-		// trim mounted drive to recover disk space
-		l.Provision = append(l.Provision, Provision{
-			Mode:   ProvisionModeSystem,
-			Script: `readlink /sbin/fstrim || fstrim -a`,
-		})
 	}
 
 	// network setup
@@ -227,19 +222,26 @@ func newConf(ctx context.Context, conf config.Config) (l Config, err error) {
 	}
 
 	switch strings.ToLower(conf.MountType) {
-	case "", "ssh", "sshfs", "reversessh", "reverse-ssh", "reversesshfs", REVSSHFS:
+	case "ssh", "sshfs", "reversessh", "reverse-ssh", "reversesshfs", REVSSHFS:
 		l.MountType = REVSSHFS
 	default:
-		l.MountType = NINEP
-		l.Provision = append(l.Provision, Provision{
-			Mode:   ProvisionModeSystem,
-			Script: "mkmntdirs && mount -a",
-		})
+		if l.VMType == VZ {
+			l.MountType = VIRTIOFS
+		} else { // qemu
+			l.MountType = NINEP
+		}
 	}
 
-	if l.VMType == VZ {
-		l.MountType = VIRTIOFS
-	}
+	l.Provision = append(l.Provision, Provision{
+		Mode:   ProvisionModeSystem,
+		Script: "mkmntdirs && mount -a",
+	})
+
+	// trim mounted drive to recover disk space
+	l.Provision = append(l.Provision, Provision{
+		Mode:   ProvisionModeSystem,
+		Script: `readlink /sbin/fstrim || fstrim -a`,
+	})
 
 	if len(conf.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
